## reference #######################################################################################################

For quick reference an example value has been provided too:

1. [data types](#data-types)
	* [`Standard::AbsoluteDirectoryName`](#standardabsolutedirectoryname) – `'/.'`
	* [`Standard::AbsolutePathname`](#standardabsolutepathname) – `'/dev/urandom'`
	* [`Standard::FileMode`](#standardfilemode) – `01755`
	* [`Standard::Filename`](#standardfilename) – `'.'`
	* [`Standard::FQDN`](#standardfqdn) – `'puppet.com.'`
	* [`Standard::FullyQualifiedDomainName`](#standardfullyqualifieddomainname) – `'puppetlabs.com.'`
	* [`Standard::InternetProtocolVersion4address`](#standardinternetprotocolversion4address) – `134743044`
	* [`Standard::Line`](#standardline) – `"Hello world!\n"`
	* [`Standard::NormalizedPortableAbsolutePathname`](#standardnormalizedportableabsolutepathname) – `'/dev/null'`
	* [`Standard::OrdinaryPortableFilename`](#standardordinaryportablefilename) – `'rc.conf'`
	* [`Standard::OrdinaryPortableFilenameDictionary`](#standardordinaryportablefilenamedictionary) – `{'abc' => 'def'}`
	* [`Standard::PartiallyQualifiedDomainName`](#standardpartiallyqualifieddomainname) – `'puppetlabs.com'`
	* [`Standard::Pathname`](#standardpathname) – `'.profile'`
	* [`Standard::PortableAbsoluteDirectoryName`](#standardportableabsolutedirectoryname) – `'/etc/.'`
	* [`Standard::PortableAbsolutePathname`](#standardportableabsolutepathname) – `'/dev//urandom'`
	* [`Standard::PortableFilename`](#standardportablefilename) – `'..'`
	* [`Standard::PortableGroupName`](#standardportablegroupname) – `'wheel'`
	* [`Standard::PortablePathname`](#standardportablepathname) – `'.profile'`
	* [`Standard::PortableRelativePathname`](#standardportablerelativepathname) – `'..'`
	* [`Standard::PortableUserName`](#standardportableusername) – `'root'`
	* [`Standard::PQDN`](#standardpqdn) – `'puppet.com'`
	* [`Standard::ShellCommandLanguageName`](#standardshellcommandlanguagename) – `'LC_ALL'`
	* [`Standard::SpecialFilename`](#standardspecialfilename) – `'..'`
	* [`Standard::SpecialPortableFilename`](#standardspecialportablefilename) – `'..'`
	* [`Standard::SymbolicFileModeBits`](#standardsymbolicfilemodebits) – `'u=rwx,go=rx'`
	* [`Standard::SystemErrorLogFacility`](#standardsystemerrorlogfacility) – `'LOG_DAEMON'`
	* [`Standard::SystemErrorLogPriority`](#standardsystemerrorlogpriority) – `'LOG_ERR'`
	* [`Standard::VisiblePortableCharacterSetString`](#standardvisibleportablecharactersetstring) – `'&'`
2. [functions](#functions)
	* [`standard::directory_name`](#standarddirectory_name) – `'/'`
	* [`standard::dotted_decimal`](#standarddotted_decimal) – `'123.456.789'`
	* [`standard::internet_protocol_version_4_address`](#standardinternet_protocol_version_4_address) – `134743044`
3. [templates](#templates)
	* [`standard/character_set_description.epp`](#standard%2Fcharacter_set_descriptionepp) – (too long)
	* [`standard/shell_variable_assignments.epp`](#standard%2Fshell_variable_assignmentsepp) – `'VARIABLE=word'`


### data types #####################################################################################

pathnames:

* absolute
	* [`Standard::AbsoluteDirectoryName`](#standardabsolutedirectoryname) – ends on `/.`
	* [`Standard::AbsolutePathname`](#standardabsolutepathname)
	* [`Standard::NormalizedPortableAbsolutePathname`](#standardnormalizedportableabsolutepathname) – no repeating slashes
	* [`Standard::PortableAbsoluteDirectoryName`](#standardportableabsolutedirectoryname)
	* [`Standard::PortableAbsolutePathname`](#standardportableabsolutepathname) – no weird characters
* relative
	* [`Standard::PortableRelativePathname`](#standardportablerelativepathname) – not beginning with `/`
	* [`Standard::PortableFilename`](#standardportablefilename)
	* [`Standard::SpecialFilename`](#standardspecialfilename) – same or parent directory
	* [`Standard::SpecialPortableFilename`](#standardspecialportablefilename)
* either
	* [`Standard::Filename`](#standardfilename) – a directory, a regular file, or anything else
	* [`Standard::OrdinaryPortableFilename`](#standardordinaryportablefilename) – excludes same or parent directory
	* [`Standard::Pathname`](#standardpathname) – just a string
	* [`Standard::PortablePathname`](#standardportablepathname) – just a string restricted to certain characters
* map
	* [`Standard::OrdinaryPortableFilenameDictionary`](#standardordinaryportablefilenamedictionary)

file mode bits:

* [`Standard::FileModeBits`](#standardfilemodebits) – symbolic or numeric file mode bits
* [`Standard::SymbolicFileModeBits`](#standardsymbolicfilemodebits) – only symbolic file mode bits

user and group names:

* [`Standard::PortableGroupName`](#standardportablegroupname)
* [`Standard::PortableUserName`](#standardportableusername)

networking:

* [`Standard::FQDN`](#standardfqdn) – alias for fully‑qualified domain name
* [`Standard::FullyQualifiedDomainName`](#standardfullyqualifieddomainname)
* [`Standard::InternetProtocolVersion4address`](#standardinternetprotocolversion4address) – an integer range
* [`Standard::PartiallyQualifiedDomainName`](#standardpartiallyqualifieddomainname)
* [`Standard::PQDN`](#standardpqdn) – alias for partially‑qualified domain name

data:

* [`Standard::ShellCommandLanguageName`](#standardshellcommandlanguagename)
* [`Standard::Line`](#standardline) – a string that constitutes a line
* [`Standard::SystemErrorLogFacility`](#standardsystemerrorlogfacility)
* [`Standard::SystemErrorLogPriority`](#standardsystemerrorlogpriority)
* [`Standard::VisiblePortableCharacterSetString`](#standardvisibleportablecharactersetstring)

[↑ back to top ↑](#reference)


#### `Standard::AbsoluteDirectoryName` #############################################

description:

* This is like [`Standard::AbsolutePathname`](#standardabsolutepathname)
  except that it must _end_ with slash‐dot (`/.`) thus (unambiguously) identifying a directory.
* Some authors use _just_ a trailing slash to denote directories.
  This, however, merely distinguishes a symbolic link (i. e. the file that implements the symbolic link)
  vs. the resolved symbolic link (i. e. the target a symbolic link points to).
  If the resolved symbolic link does not point to a directory, an error is emitted.
* The final dot is added so that the standardized `dirname` utility (return the directory portion of a pathname)
  returns the directory file name.

examples:

* `'/.'`

compliance:

* POSIX.1‑2024
	* The notion of “absolute directory name” is not mentioned explicitly.
	* ✘ Pathnames ending on `'/..'` are not accepted. It is assessed to be more likely a mistake.


#### `Standard::AbsolutePathname` ##################################################

description:

* This is [`Standard::Pathname`](#standardpathname) except that
  it must start with one or _more than_ two slashes (`/`).

examples:

* `'/x/y/z'`
* `'/home/example_user/文件'`
* `'////'`

compliance:

* POSIX.1‑2024
	* ✔ begins with one or _more than_ two slash (`/`) characters


#### `Standard::FileModeBits` ######################################################

description:

* A filemode is either a non‐negative `Integer` ≤ 7777₈ or [`Standard::SymbolicFileModeBits`](#standardsymbolicfilemodebits).

example:

* `0644`

compliance:

* POSIX.1‑2024
	* ✔ the `Integer` variant corresponds to `mode_t`


#### `Standard::Filename` ##########################################################

description:

* A filename is a non‐empty sequence of bytes excluding the values for NUL and slash (`/`).

examples:

* `'Meine Überdatei²'`
* `"Robert'); DROP TABLE Students;"`

compliance:

* POSIX.1‑2024
	* ✔ Note this data type cannot observe the `NAME_MAX` length limit.
	  On a POSIX‐compliant system this value is at least 14 (fourteen) bytes.


#### `Standard::FullyQualifiedDomainName` ##########################################

description:

* This data type provides _a very limited subset_ of possible FQDNs.
  It is a `String` data type implemented via regular expressions.
  It matches _up to five labels_ plus a final empty label (the root label).
  Labels are separated from each other by a single dot (`.`).
* A label is a non‐empty sequence of up to 63 ASCII letters or digits (A – Z, a – z, 0 – 9).
	* The first character must be a letter.
	* In the middle dashes (`-`) may appear too.
* The entire string’s length may not exceed 255 characters.
  Due to the implementation via regular expressions
  (as a compromise)
  the labels’ maximum length varies if five labels need to be specified (57, 56, 56, 56, 24).
  The limits are subject to adjustment.
* In many contexts in fact a fully‐qualified domain name is expected
  but the terminating separator for the root label is treated as an error.
  Use the [built‑in `chop` function](https://www.Puppet.com/docs/puppet/latest/function#chop) to remove the root label separator,
  or use [`Standard::PartiallyQualifiedDomainName`](#standardpartiallyqualifieddomainname)
  if a (as in _any_) PQDN is acceptable, too.

examples:

* `'forge.puppet.com.'`
* `'xn--7qv.xn--ses554g.'`
* `'1.0.0.127.IN-ADDR.ARPA.'`

limited compliance:

* [RFC 1035](https://datatracker.IETF.org/doc/html/rfc1035)
	* ✔ “The domain name terminates with the zero length octet for the null label of the root.”
	* ✔ Labels are composed of ASCII letters and digits.
	* ✔ “The labels must follow the rules for ARPANET host names.
	     They must start with a letter, end with a letter or digit,
	     and have as interior characters only letters, digits, and hyphen.”
	* ✔ “Labels must be 63 characters or less.”
	* ✔ “[…] the total length of a domain name […] is restricted to 255 octets or less.”
	* ✔ “`IN-ADDR.ARPA` domain”
	* ✘ `Standard::FullyQualifiedDomainName` is capped to to six labels (including the root label).
	  _Technically_ it ought to be possible to accept up to 127 labels.


#### `Standard::FQDN` ##############################################################

description:

* This is an alias for [`Standard::FullyQualifiedDomainName`](#standardfullyqualifieddomainname).
  If the context implies the meaning of the acronym FQDN, you may use this identifier.
  However, its removal (e. g. outsourcing to a different module focusing on network management) is considered.


#### `Standard::InternetProtocolVersion4address` ###################################

description:

* This is a non‐negative integer less than 2³².

examples:

* `2130706433`
* `0xFEDCBA98`

compliance:

* POSIX.1‑2024
	* ✔ corresponds to `in_addr_t` (which is equivalent to `uint32_t`)
* [RFC 791](https://datatracker.ietf.org/doc/html/rfc791)
	* `Standard::InternetProtocolVersion4address` is _at least_ a 32‑bit quantity.


#### `Standard::Line` ##############################################################

description:

* A line is a possibly empty sequence of non‐newline characters concluding with a single newline character.

example:

* `"Hello world!\n"`

compliance:

* POSIX.1‑2024


#### `Standard::NormalizedPortableAbsolutePathname` ################################

description:

* This is [`Standard::PortableAbsolutePathname`](#standardportableabsolutepathname),
  but it may not contain consecutive slash characters.
* It has not yet been decided
  whether this application case should be implemented via a custom data type (a regular expression to be precise)
  or whether a (set of) function(s) would be more adequate.
  Deliberation is mainly driven by considering which situations should lead to a catalog compilation failure.
  Evidently `'/foo///bar'` is a valid pathname and will be accepted by the operating system.


#### `Standard::OrdinaryPortableFilename` ##########################################

description:

* The [filenames `'.'` and `'..'` are special](#standardspecialfilename)
  (conveying _same directory_ and _parent directory_ respectively).
  This data type is [`Standard::PortableFilename`](#standardportablefilename) but it does not match said special filenames.

example:

* `'rc.conf'`

limited compliance:

* POSIX.1‑2024
	* The notion of “ordinary portable filename” is not expressly defined.
	* This data type cannot observe the `NAME_MAX` limit (the minimum is 14).


#### `Standard::OrdinaryPortableFilenameDictionary` ################################

description:

* This is merely a [`Hash`](https://www.Puppet.com/docs/puppet/latest/lang_data_hash.html)
  that has [`Standard::OrdinaryPortableFilename`](#standardordinaryportablefilename) both as key and value.

examples:

* `{}`
* `{'std' => 'standard'}`

no compliance:

* This is a convenience definition not backed by specfic standard definitions.


#### `Standard::PartiallyQualifiedDomainName` ######################################

description:

* This is [`Standard::FullyQualifiedDomainName`](#standardfullyqualifieddomainname)
  but _a final dot must be absent_.
  Accordingly the length is capped at 254 characters.
* To be logically consistent `IN-ADDR.ARPA` addresses are _not_ available.
  The root domain (that is the string `'.'`) cannot be specified either.

examples:

* `'www.example.com'`
* `'forge.puppet.com'`

compliance:

* See [`Standard::FullyQualifiedDomainName`](#standardfullyqualifieddomainname)
  with the exception of a final dot in mind.


#### `Standard::PQDN` ##############################################################

description:

* This is an alias for [`Standard::PartiallyQualifiedDomainName`](#standardpartiallyqualifieddomainname).
  If the context implies the meaning of the acronym PQDN, you may use this identifier.
* Notice: A removal (outsourcing to a different module focusing on network management) is considered.


#### `Standard::Pathname` ##########################################################

description:

* This is a `String` data type. Strings must be non‐empty.
* A terminating NUL character is implicit and must not be indicated.

example:

* `'קובץ'`

compliance:

* POSIX.1‑2024
	* ✔ Note, there is no observance of `PATH_MAX`. On a POSIX‐compliant systems this is at least 256 bytes.


#### `Standard::PortableAbsoluteDirectoryName` #####################################

description:

* This is like [`Standard::PortableAbsolutePathname`](#standardportableabsolutepathname)
  except that it must _end_ with slash‐dot (`/.`) thus (unambiguously) identifying a directory.
* Some authors use just a trailing slash to denote directories.
  This distinguishes a symbolic link (i. e. the file that implements the symbolic link)
  vs. the resolved symbolic link (i. e. the target a symbolic link points to).
  If the resolved symbolic link does not point to a directory, an error is emitted.
* The final dot is added so that the standardized `dirname` utility (return the directory portion of a pathname)
  returns the directory file name.

examples:

* `'/etc/rc.conf.d/.'`

compliance:

* POSIX.1‑2024
	* The notion of “portable absolute directory name” is not mentioned explicitly.
	* ✘ Pathnames ending with `'/..'` are not accepted.
	  It is assessed to be more likely a mistake.


#### `Standard::PortableAbsolutePathname` ##########################################

description:

* This is [`Standard::PortablePathname`](#standardportablepathname) except that
  it must start with one or _more than_ two slashes (`/`).

examples:

* `'/var/log//kern.log'`

compliance:

* POSIX.1‑2024
	* ✔ begins with one or _more than_ two slash (`/`) characters


#### `Standard::PortableFilename` ##################################################

description:

* Filenames are a non‐empty sequence of characters _except slashes and NUL‐characters_.
  This data type is restricted to the “portable filename character set”
  thus only modern Latin alphabet letters, Western‐Arabic digits,
  underscores, dots, and dashes are accepted.
* Note, filenames starting with a dash (`-`) are accepted.
  They may cause troubles on the command line interface
  _if supplied as the first component_ of a working‐directory‐relative pathname.

examples:

* `'..'`
* `'crash.dump'`

compliance:

* POSIX.1‑2024
	* ✔ Note this data type cannot observe the `NAME_MAX` length limit.
	  On a POSIX‐compliant system this value is at least 14 (fourteen) bytes.


#### `Standard::PortablePathname` ##################################################

description:

* A portable pathname is a [`Standard::Pathname`](#standardpathname) restricted to
  the portable filename character set and slash characters.
  A terminating NUL character is not indicated.

examples:

* `'//proxy`

compliance:

* POSIX.1‑2024
	* ✔ with the consideration of NUL characters


#### `Standard::PortableGroupName` #################################################

description:

* This is identical to [`Standard::PortableUserName`](#standardportableusername).
  This data type is primarily provided for documentation purposes.

example:

* `'wheel'`

compliance:

* POSIX.1‑2024


#### `Standard::PortableRelativePathname` ##########################################

description:

* This is [`Standard::PortablePathname`](#standardportablepathname) except that it may not start with a slash.

examples:

* `'./reference.md'`
* `'puppet/../..'`

compliance:

* POSIX.1‑2024
	* ✔ does not begin a slash (`/`) character


#### `Standard::PortableUserName` ##################################################

description:

* A portable user name is a non‐empty string composed of ASCII letters and digits, dots, underscores, and dashes.
  The first character may not be a dash.
  (A leading dash usually indicates an option in the command‐line interface.)
* This data type accepts all‐numeric user names, too,
  and they should be accepted for interoperability reasons,
  but for _new_ user names it is recommended to restrict the set of acceptable user names even further:
  humans may confuse reported digit strings for the numeric user ID,
  and some command‐line tools do not allow you to specify a numeric user ID anymore if it coincides with a user’s name.

example:

* `'puppet'`

compliance:

* POSIX.1‑2024
	* ✔ Note that the `LOGIN_NAME_MAX` length limit cannot be observed.
	  On a POSIX‐compliant system this limit permits _at least_ 8 characters for a user name.
	  For maximum portability cap your user names at eight characters.


#### `Standard::ShellCommandLanguageName` ##########################################

description:

* A _name_ in the (POSIX) shell command language.
  It consists of a non‐empty sequence of modern Latin alphabet characters, Western‐Arabic digits, and underscores.
  The first character, however, may not be a digit.

examples:

* `'foobar'`
* `'LD_SHOW_AUXV'`

compliance:

* POSIX.1‑2024
	* ✔ fully‐compliant to “name” as specified in the Base Definitions


#### `Standard::SpecialFilename` ###################################################

description:

* The file names `'.'` and `'..'` have special meaning
  conveying current directory or parent directory respectively.
* This data type is primarily provided for meaningful `=~` data type matching.
  ```puppet
  if $my_value =~ Standard::SpecialFilename { fail('$my_value may not be special.') }
  ```

all values:

* `'.'`
* `'..'`

compliance:

* POSIX.1‑2024
	* the category of special file name is inferred


#### `Standard::SpecialPortableFilename` ###########################################

description:

* This is an alias for [`Standard::SpecialFilename`](#standardspecialfilename).
  However, use of this identifier can be deemed confusing
  since “portable” does not add any quality to the permitted values.
  It is only provided to supply an orthogonal set of identifiers.


#### `Standard::SymbolicFileModeBits` ##############################################

description:

* A spelled out file mode bits description suitable as `mode` attribute of a `file` resource or for tools such as `chmod`.

example:

* `'u=rw,go=r'` (the owning user has read and write permissions, the owning group and others have read permissions)

compliance:

* POSIX.1‑2024
	* ✔ fully‐compliant to `symbolic_mode` described in `chmod`.


#### `Standard::SystemErrorLogFacility` ############################################

description:

* A symbolic constant name for a system error log facility.

example:

* `'LOG_DAEMON'`

compliance:

* POSIX.1‑2024
	* The Puppet ® data type matches string values, but should be identifiers.
	  You cannot specify valid values as
	  [bare words](https://www.Puppet.com/docs/puppet/latest/lang_data_string#lang_data_string_bare_words), though,
	  since the first letter is a capital letter.

#### `Standard::SystemErrorLogPriority` ############################################

description:

* A symbolic constant name for a system error log priority.

example:

* `'LOG_DEBUG'`

compliance:

* POSIX.1‑2024
	* The Puppet ® data type matches string values, but should be identifiers.
	  You cannot specify valid values as
	  [bare words](https://www.Puppet.com/docs/puppet/latest/lang_data_string#lang_data_string_bare_words), though,
	  since the first letter is a capital letter.


#### `Standard::VisiblePortableCharacterSetString` #################################

description:

* A non‑empty string consisting solely of character drawing from the visible portion of the portable character set.

example:

* `'?'`

compliance:

* POSIX.1‑2024
	* The notion of a visible PCS string is not explicitly defined.


### functions ######################################################################################

pathnames:

* [`standard::directory_name`](#standarddirectory_name) – obtain directory name from string

networking:

* [`standard::dotted_decimal`](#standarddotted_decimal) – turn an integer into a string
* [`standard::internet_protocol_version_4_address`](#standardinternet_protocol_version_4_address) – numeric value from string

[↑ back to top ↑](#reference)


#### `standard::directory_name` ####################################################

description:

* This is a wrapper for [Ruby’s `File.dirname` function](https://Ruby-doc.org/core/File.html#method-c-dirname).

example:

* `standard::directory_name('//foo')` returns `'/'`

compliance:

* POSIX.1‑2024
	* Ruby documentation does not make any assertions
	  and the implementation has not been verified,
	  but it is expected to correspond to the `dirname` function


#### `standard::dotted_decimal` ####################################################

description:

* This function takes a non‐negative integer and converts it to a string using the dotted decimal notation.
* The second integer parameter denotes the maximum range per group. It must be greater than one (`1`).
* The optional third positive integer parameter will augment leading zero‐groups.

examples:

* `standard::dotted_decimal(0xFF00, 256)` yields `'255.0'`
* `standard::dotted_decimal(0x7F000001, 256, 4)` yields `'127.0.0.1'`

compliance:

* POSIX.1‑2024
	* If invoked as `standard::dotted_decimal($n, 256, 4)` this corresponds to `inet_ntoa` in functionality
	  _unless_ `$n` exceeds the value of [`0xFFFFFFFF`](#standardinternetprotocolversion4address).


#### `standard::internet_protocol_version_4_address` ###############################

description:

* The function takes a non‐empty string containing hexadecimal digits, the letter `x` and dots.

examples:

* `standard::internet_protocol_version_4_address('127.123.45678')` yields `2138813038`
* `standard::internet_protocol_version_4_address('255.255.255.255')` yields `4294967295`

compliance:

* POSIX.1‑2024
	* ✔ This function corresponds to `inet_addr`.
	* ✔ accepts octal, decimal, hexadecimal parts
	* ✔ up to four parts with shift applied


### templates ######################################################################################

programming languages:

* [`standard/shell_variable_assignments.epp`](#standard%2Fshell_variable_assignmentsepp) – shell variable assignments

data:

* [`standard/character_set_description.epp`](#standard%2Fcharacter_set_descriptionepp) – character set description file

[↑ back to top ↑](#reference)


#### `standard/character_set_description.epp` ######################################

description:

* Two character set description files can be supplied to the standardized `iconv` utility.
  This allows you to translate between character set encodings, provided all input coded characters are defined in both sets.
* The template requires two parameters, `code_set_name` and `map`.
  The `code_set_name` is a [`Standard::VisiblePortableCharacterSetString`](#standardvisibleportablecharactersetstring).
  The `map` is a non‑empty `Hash`.
  The keys must match `Standard::VisiblePortableCharacterSetString`.
  The values are either non‑empty arrays of byte values (integers in the range 0 to 255 inclusive),
  or another `Hash`.
  If it is another `Hash`, there must be a key `encoding` that is a non‑empty array of byte values.
  There may be additional keys `width` and `comment`.
  The `width` is an `Integer` value and comment is a `String`.
* The parameters `mb_cur_min_`, `mb_cur_max` and `default_width` are by default all `1`.
* You can supply alternative parameter values for `comment_char` and `escape_char`.
  However, there are only few characters accepted because of existent implementations.
  For example a GNU C library version of `iconv` does/did not accept `;` (semicolon) as a comment character.
* Furthermore, the template accepts the optional parameters `comment` and `footer`.
  The former is a commented string appearing above the `CHARMAP`.
  The latter is a commented string appearing at the end of the file.
  If `comment` is left `undef`ined, a column header line is printed if it is determined to align with the columns.
* You can influence formatting:
  The `Integer` parameter `column_symbolic_name_minimum_width` is by default `32`.
  The `Integer` parameter `column_byte_string_minimum_width` is by default `16`.
  Adjust them to your taste.

example:

* `epp('standard/character_set_description.epp', {code_set_name => 'ABC', map => {'X' => [42]}})` yields
  ```
  <code_set_name> "ABC"
  
  # symbolic_name,                 byte string,     comment
  
  CHARMAP
  <X>                                          \052
  END CHARMAP
  ```

compliance:

* POSIX.1‑2024
	* Because the domains of `comment_char` and `escape_char` are restricted to a few characters,
	  this template can render a only a _subset_ of possible character maps.
  * This template does in no way ensure that all characters of the portable character set are part of `map`.
	  (“Each character set description file […] shall define characteristics for the coded character set
	    and the encoding for the characters specified in Portable Character Set […]”)


#### `standard/shell_variable_assignments.epp` #####################################

description:

* Applications employing the KISS principle frequently use shell‐based configuration files
  if there is no demand for complicated constructs.
* This template provides a quick way to fill a file with a host of _variable assignments_.
  The mandatory parameter **`$setting`** is a `Hash`.
  Acceptable keys are [`Standard::ShellCommandLanguageName`](#standardshellcommandlanguagename).
  Acceptable values are `ScalarData` (that is `Boolean`, `Integer`, `Float` and `String` data types).
* Integer, float and Boolean values are rendered using the automatic conversion mechanisms Puppet ® provides.
  Optional `$integer_format`, `$float_format` and `$boolean_format` string parameters may override this.
  See [Puppet’s function reference](https://www.Puppet.com/docs/puppet/latest/function#conversion-to-string) for details.
* Strings are surrounded by inch signs (`"`) if they contain anything to expand (e. g. shell variables), 
  otherwise typewriter apostrophes (`'`) are used.
* It is recommended to _verify_ that the application at hand uses a shell‐based configuration _by design_,
  or whether its resemblance is a mere coincidence
  (and thus a later application version may significantly deviate from it).

example:

* `epp('standard/shell_variable_assignments.epp', {$setting => {'FOO' => 'bar'}})` yields
  ```shell
  FOO='bar'
  ```

limited compliance:

* POSIX.1‑2024
	* It has not been established that it is impossible to pass values
	  that will render this template’s output invalid shell input.
	  Therefore setting [`validate_cmd`](https://www.Puppet.com/docs/puppet/latest/types/file#file-attribute-validate_cmd)
	  to `'/bin/sh ‑o noexec %'` is recommended.


[//]: # ( vim: set filetype=markdown textwidth=132 tabstop=2 noexpandtab backspace=eol,start,indent: )
